export const alerts = { error: 'some-error' };
export const caption = 'some caption';
export const logoSrc = '/some-logo';
export const token = 'some token';

export const props = {
  alerts,
  caption,
  logoSrc,
  token,
};
